@@ -4,7 +4,7 @@
 
 package Mesoderm;
 {
-  $Mesoderm::VERSION = '0.122120';
+  $Mesoderm::VERSION = '0.122290';
 }
 use Moose;
 
@@ -458,7 +458,7 @@ sub write_table {
 
   my $comp_init = $self->write_components($fh, $table);
 
-  print $fh "  with '$_';\n" for $self->table_roles($table), $mesoderm_role;
+  print $fh "  with qw(",join("\n    ","",$self->table_roles($table), $mesoderm_role ,");\n");
   print $fh "  no Moose;\n\n";
 
   print $fh "  __PACKAGE__->table('", $table->name, "');\n";
@@ -521,7 +521,7 @@ sub write_table {
   print $fh "  { package $resultset_class;\n";
   print $fh "    use Moose;\n";
   print $fh "    extends 'DBIx::Class::ResultSet';\n";
-  print $fh "    with '$_';\n" for $self->resultset_roles($table), $mesoderm_role;
+  print $fh "    with qw(",join("\n      ","",$self->resultset_roles($table), $mesoderm_role ,");\n");
   print $fh "    no Moose;\n";
   print $fh "  }\n";
   print $fh "  __PACKAGE__->resultset_class('$resultset_class');\n";
@@ -617,7 +617,7 @@ Mesoderm - Schema class scaffold generator for DBIx::Class
 
 =head1 VERSION
 
-version 0.122120
+version 0.122290
 
 =head1 SYNOPSIS
 
